# CLI Reference

This page provides auto-generated documentation for the `crowdcent` CLI for the CrowdCent Challenge.

::: mkdocs-click
    :module: crowdcent_challenge.cli
    :command: cli
    :prog_name: crowdcent
    :depth: 1